<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * UserGenerationForm class
 *
 */
class GenerationForm extends CFormModel
{
    /**
     * @var integer
     * @desc quantity of users to generate
     */
    public $usersQty;

    public $likesQty;

    public $likesContentId;

    public $commentsQty;

    public $commentsForEach;

    public $commentsContentId;

    /**
     * Declares the validation rules.
     * The rules state that userQty is required and must be an integer,
     *
     * @return array
     */
    public function rules()
    {
        return array(
            // usersQty is required and must be an integer
            array('usersQty, likesQty, commentsQty', 'numerical', 'integerOnly' => true),
            array('commentsForEach', 'boolean'),
            array('likesContentId, commentsContentId', 'length', 'max' => 255),
            //array('likesContentId, commentsContentId', 'exists'),
        );
    }

    /**
     * Checks if given contentId already exist
     *
     * @param string $field defines what field should be checked
     *
     * @return bool
     */
    public function exists($field)
    {
        if ($field == 'likesContentId' && (!empty($this->likesQty) && empty($this->likesContentId))) {
            $this->addError('likesContentId', 'Likes content id can\'t be empty');
            return false;
        }
        if ($field == 'commentsContentId' && (!empty($this->commentsQty) && empty($this->commentsContentId))) {
            $this->addError('likesContentId', 'Comments content id can\'t be empty');
            return false;
        }

        return true;
    }

    /**
     * Declares attribute labels.
     * 
     * @return array
     */
    public function attributeLabels()
    {
        return array(
            'usersQty' => BulkModule::t("Users quantity"),
            'likesQty' => BulkModule::t("Likes quantity"),
            'commentsQty' => BulkModule::t("Comments quantity"),
            'likesForEach' => BulkModule::t("For each user"),
            'commentsForEach' => BulkModule::t("For each user"),
            'likesContentId' => BulkModule::t("Content id"),
            'commentsContentId' => BulkModule::t("Content id"),
        );
    }
}