<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Widget for view comments for current model
 */

class LikeWidget extends BaseJuiWidget
{
    /**
     * @var model for displaying likes
     */
    public $model;

    /**
     * @var integer
     * @desc ID of content to be liked or unliked
     */
    public $contentId;

    /**
     * @var integer
     * Defines how many likers should be shown in div on mouseover.
     * if this paremeter equal to zero - no additional likes would be shown
     */
    public $lastLikesQty;

    /**
     * @var integer
     * Defines how many likers should be shown in without div.
     * if this paremeter equal to zero - no additional likes would be shown
     */
    public $topLikesQty;

    /**
     * @var integer
     * @desc quantity of likes for given content
     */
    public $likesQty;

    /**
     * @array
     * @desc containing info about likes of given content
     */
    public $likes;

    /**
     * @bool
     * @desc flag if user has likes this content before
     */
    public $hasLiked = false;


    /**
     * @bool
     * @desc flag if JavaScript should be available
     */
    public $isPreview = false;

    /**
     * Initializes the widget.
     *
     * @return void
     */
    public function init()
    {
    }

    /**
     * Selects model and renders view
     *
     * @return void
     */
    public function run()
    {
        $this->model = $this->_loadModel();

        /*  show widget only if we have $this->model->content_id */
        if ($this->model->content_id > 0) {
            /*  get total likes quantity for current content*/
            $this->likesQty = $this->model->likesQty;

            /*  get top and last likes depending on config set above */
            $this->likes = $this->model->likes;

            //if not guest set current user like at first position
            if (!Yii::app()->user->isGuest) {
                if (!empty($this->model->likes)) {
                    $likes = $this->model->likes;
                    for ($i = 0; $i < count($likes); $i++) {
                        if ($likes[$i]->user_id == Yii::app()->user->id) {
                            $this->hasLiked = true;
                            $tmp = $likes[0];
                            $likes[0] = $likes[$i];
                            $likes[$i] = $tmp;
                            break;
                        }
                    }
                    $this->model->likes = $likes;
                }
            }

            $this->render('LikeWidget', array('model' => $this->model, 'hasLiked' => $this->hasLiked));
        }
    }

    /**
     * Load like model from cache. If not exists create empty.
     *
     * @return Like
     */
    private function _loadModel()
    {
        $cacheId = 'likeLike_' . $this->contentId;
        //Load model
        if (($model = Yii::app()->cache->get($cacheId)) === false) {
            Yii::trace($this->contentId.' IS NOT CACHED', 'Like cache');

            $model = new Like();
            /*  set likes qty limitations */
            $model->lastLikesQty = Yii::app()->getModule('like')->lastLikesQty;
            $model->topLikesQty = Yii::app()->getModule('like')->topLikesQty;
            $model->content_id = $this->contentId;
            //set default values for better performance
            $model->getLikes();
            $model->getLikesQty();

            $limit = intval($model->lastLikesQty + $model->topLikesQty);

            //smart "cache changed" dependency
            if (Yii::app()->db->getDriverName() == 'mysql') {
                //use MySql specific function for dependency
                $dependency = new CDbCacheDependency('SELECT group_concat(id, "-" ,user_id) FROM ' . Like::model()->tableName() . ' WHERE content_id=:content_id ORDER BY createdate DESC LIMIT '.$limit);
                $dependency->params['content_id'] = $this->contentId;
            } else {
                //use general sql expression for all db. more memory usage
                $dependency = new CExpressionDependency(
                    'Yii::app()->db->createCommand()->select("id, user_id")->from(Like::model()->tableName())->where("content_id=:content_id", array("content_id" => "' . $this->contentId . '"))->order("createdate DESC")->limit('.$limit.')->queryAll()'
                );
            }
            //store in cache
            Yii::app()->cache->set($cacheId, $model, Yii::app()->getModule('like')->cacheTime, $dependency);
        } else {
            Yii::trace($this->contentId.' WAS CACHED', 'Like cache');
        }

        return $model;
    }
}

?>
