<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 *
 * @author Vitalii Kovalchuk <vitaly.kovalchuk@oberig.com>
 */

/**
 * PersonalizedContent controller class
 *
 * @author Vitalii Kovalchuk <vitaly.kovalchuk@oberig.com>
 *
 */
class PreviewController extends Controller
{

    /**
     * default action used to show widget preview
     *
     * @return void
     *
     * @throws Exception
     */
    public function actionIndex()
    {
        $folderIds = Yii::app()->request->getQuery('folderIds', null);
        $pageId = Yii::app()->request->getQuery('pageId', null);
        $usePersonalisation = Yii::app()->request->getQuery('usePersonalisation', 'Y');
        $lang = Yii::app()->request->getQuery('lang', null);

        if (empty($folderIds)) {
            throw new Exception(PersonalizedContentModule::t('PersonalizedContentPreview error: folderIds is required and can`t be blank'));
        } else if (empty($pageId)) {
            throw new Exception(PersonalizedContentModule::t('PersonalizedContentPreview error: pageId is required and can`t be blank'));
        }

        if (empty($lang)) {
            $lang = substr(Yii::app()->language, 0, 2);
        }

        $folderIds = explode(',', $folderIds);
        foreach ($folderIds as &$folderId) {
            $folderId = '10002.'.intval($folderId);
        }

        $data = Yii::app()->repositoryApi->request(
            array(
                'filter' => 'object.languagecode=="'.$lang.'" AND object.contentid=='.$pageId,
                'type' => 'php',
            ),
            array('content')
        );
        $data = unserialize($data);

        $tplString = !empty($data[$pageId]['attributes']['content']) ? $data[$pageId]['attributes']['content'] : '';
        /*$tplString = '<div class="personalized-content-item">
           <a href="{{url}}">{{name}}</a>
           <br/>
           <a href="{{url}}">{{url}}</a>
           <br/>
           <span>{{content}}</span>
           date:{{date}}<br/>
           time:{{time}}<br/>
           datetime:{{datetime}}<br/>
       </div>';*/

        if (empty($tplString)) {
            throw new Exception(PersonalizedContentModule::t('PersonalizedContentPreview error: could not load tplString from GCC or it is empty'));
        }

        $this->widget(
            'personalizedContent.widgets.PersonalizedContentWidget',
            array(
                'folderIds'=>$folderIds,
                'tplString'=>$tplString,
                'usePersonalisation'=>($usePersonalisation == 'Y' ? true : false)
            )
        );
    }
}
