<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 *
 */
class ReleaseController extends BaseController
{


    /**
     * Sets access filters
     *
     * @return array
     */
    public function filters()
    {
        return array(
            'accessControl'
        );
    }

    /**
     * Sets access rules
     *
     * @return array
     */
    public function accessRules()
    {
        return array(
            array('allow',
                'actions' => array('create', 'updateStep1', 'updateStep2', 'updateStep3'),
                'roles' => array('Admin'),
            ),
            array('deny',
                'users' => array('*'),
            ),
        );
    }

    /**
     * Creates a release
     *
     * @return array
     */
    public function actionCreate()
    {
        $model = new CreateReleaseForm();
        $model->invitationMessage = UpdatesModule::t('With this archive you can update Gentics Portal.Node PHP to version {version}', array('{version}' => Yii::app()->getModule('updates')->currentVersion));
        $model->invitationMessage .= "\nNOTE: Before run update check if application directory is writable!";
        $model->finishMessage = 'Successfully updated';
        if (!empty($_POST['CreateReleaseForm'])) {
            $model->attributes = $_POST['CreateReleaseForm'];
            if ($model->validate()) {
                $release = Release::make(
                    Yii::getPathOfAlias('site'),
                    array('.git', '.idea', '.gitignore', 'custom', 'frontend/runtime', 'frontend/www/assets', 'common/runtime', 'DCR', 'FSCR'),
                    $model->invitationMessage,
                    $model->finishMessage
                );
                Yii::app()->request->sendFile(pathinfo($release->getZipLocation(), PATHINFO_BASENAME), file_get_contents($release->getZipLocation()), null, false);
                exit(0);
            }
        }

        $this->render('create', array('model' => $model));
    }

    /**
     * Update action, step 1
     *
     * @throws Exception
     * @return void
     */
    public function actionUpdateStep1()
    {
        Yii::app()->user->setState('releaseFile', null);
        $model = new UpdateForm();
        if (!empty($_POST['UpdateForm'])) {
            $model->attributes = $_POST['UpdateForm'];
            $model->validate();

            $file = CUploadedFile::getInstance($model, 'file');
            if ($file && !$file->getHasError()) {
                $fileName = Yii::getPathOfAlias('site.custom.runtime') . '/' . $file->getName();
                $file->saveAs($fileName);
                Yii::app()->user->setState('releaseFile', $fileName);
                $this->redirect('updateStep2');
            } else {
                throw new Exception('Upload file error.' . ($file ? 'Code: ' . $file->getError() : ''));
            }
        }
        $this->render('updateStep1', array('model' => $model));
    }

    /**
     * Update action, step 2
     *
     * @return void
     */
    public function actionUpdateStep2()
    {
        if ($releaseFile = Yii::app()->user->getState('releaseFile')) {
            $release = new Release($releaseFile);
            $this->render('updateStep2', array('release' => $release));
        } else {
            $this->redirect('updateStep1');
        }
    }

    /**
     * Update action, step 1
     *
     * @return void
     */
    public function actionUpdateStep3()
    {
        if (isset($_POST['Update']) && ($releaseFile = Yii::app()->user->getState('releaseFile'))) {
            try {
                $backupPath = Release::backupProject(Yii::getPathOfAlias('site.custom.runtime'));
                $release = new Release($releaseFile);
                $release->update(Yii::getPathOfAlias('site'));
                //Release::migrate();
                Yii::app()->user->setState('releaseFile', null);
                $this->render('updateStep3', array('release' => $release, 'backupPath' => $backupPath));
            } catch (Exception $e) {
                Yii::app()->user->setFlash('error', UpdatesModule::t('Update process fails') . ' ' . $e->getMessage());
                $this->render('updateStep3');
            }
        } else {
            $this->redirect('updateStep1');
        }

    }

}
